==> aws-android-sdk-iot-2.7.4-sources.jar: com/amazonaws/services/iot/model/transform/SearchIndexResultJsonUnmarshaller.java <==
/*
 * Copyright 2010-2018 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.iot.model.transform;

import com.amazonaws.services.iot.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;
import com.amazonaws.util.json.AwsJsonReader;

/**
 * JSON unmarshaller for response SearchIndexResult
 */
public class SearchIndexResultJsonUnmarshaller implements
        Unmarshaller<SearchIndexResult, JsonUnmarshallerContext> {

    public SearchIndexResult unmarshall(JsonUnmarshallerContext context) throws Exception {
        SearchIndexResult searchIndexResult = new SearchIndexResult();

        AwsJsonReader reader = context.getReader();
        reader.beginObject();
        while (reader.hasNext()) {
            String name = reader.nextName();
            if (name.equals("nextToken")) {
                searchIndexResult.setNextToken(StringJsonUnmarshaller.getInstance()
                        .unmarshall(context));
            } else if (name.equals("things")) {
                searchIndexResult.setThings(new ListUnmarshaller<ThingDocument>(
                        ThingDocumentJsonUnmarshaller.getInstance()
                        )
                                .unmarshall(context));
            } else {
                reader.skipValue();
            }
        }
        reader.endObject();

        return searchIndexResult;
    }

    private static SearchIndexResultJsonUnmarshaller instance;

    public static SearchIndexResultJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new SearchIndexResultJsonUnmarshaller();
        return instance;
    }
}

==> aws-android-sdk-iot-2.15.0-sources.jar: com/amazonaws/services/iot/model/transform/SearchIndexResultJsonUnmarshaller.java <==
/*
 * Copyright 2010-2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.iot.model.transform;

import com.amazonaws.services.iot.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;
import com.amazonaws.util.json.AwsJsonReader;

/**
 * JSON unmarshaller for response SearchIndexResult
 */
public class SearchIndexResultJsonUnmarshaller implements
        Unmarshaller<SearchIndexResult, JsonUnmarshallerContext> {

    public SearchIndexResult unmarshall(JsonUnmarshallerContext context) throws Exception {
        SearchIndexResult searchIndexResult = new SearchIndexResult();

        AwsJsonReader reader = context.getReader();
        reader.beginObject();
        while (reader.hasNext()) {
            String name = reader.nextName();
            if (name.equals("nextToken")) {
                searchIndexResult.setNextToken(StringJsonUnmarshaller.getInstance()
                        .unmarshall(context));
            } else if (name.equals("things")) {
                searchIndexResult.setThings(new ListUnmarshaller<ThingDocument>(
                        ThingDocumentJsonUnmarshaller.getInstance()
                        )
                                .unmarshall(context));
            } else if (name.equals("thingGroups")) {
                searchIndexResult.setThingGroups(new ListUnmarshaller<ThingGroupDocument>(
                        ThingGroupDocumentJsonUnmarshaller.getInstance()
                        )
                                .unmarshall(context));
            } else {
                reader.skipValue();
            }
        }
        reader.endObject();

        return searchIndexResult;
    }

    private static SearchIndexResultJsonUnmarshaller instance;

    public static SearchIndexResultJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new SearchIndexResultJsonUnmarshaller();
        return instance;
    }
}
